fan_in

package
v0.0.0-...-2e9e7a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Funnel

func Funnel(sources ...<-chan int) <-chan int

Funnel starts a dedicated goroutine for each channel in list of sources that reads values from its assigned channel and forwards them to dest, a single-output channel shared by all of the goroutine

Types

This section is empty.

Jump to