pkg_stp_types

package
v0.0.0-...-2e9e7a9 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 18, 2022 License: MIT Imports: 1 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type Circuit

type Circuit func(context.Context) (string, error)

Circuit type represents the signature of the function wrapped by either circuit breaker- or by the debounce_first/debounce_last pattern (example signature)

type Effector

type Effector func(context.Context) (string, error)

Effector represents the function that interacts with the service using the retry pattern. (example signature)

type SlowFunction

type SlowFunction func(string) (string, error)

SlowFunction represents the function that is slow to respond within the timeout pattern (example signature)

type WithContext

type WithContext func(context.Context, string) (string, error)

WithContext represents the wrapper of the SlowFunction which catches the case when a function lacks context as a paramter (example signature)

Directories

Path Synopsis

Jump to