Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Split ¶
Split creates the destination channels. For each channel created, it executes a goroutine that retrieves values from source in a for loop and forwards them to their assigned output channel. Effectively, each goroutine competes for reads from source; if several are trying to read, the "winner" will be randomly determined. If source is closed, all goroutines terminate and all of the destination channels are closed.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.