Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Circuit ¶
Circuit type represents the signature of the function wrapped by either circuit breaker- or by the debounce_first/debounce_last pattern (example signature)
type Effector ¶
Effector represents the function that interacts with the service using the retry pattern. (example signature)
type SlowFunction ¶
SlowFunction represents the function that is slow to respond within the timeout pattern (example signature)
Click to show internal directories.
Click to hide internal directories.